# The "dusk" colormap was originally created by Cameron Hummels within the yt-project
import numpy as np

# Used to reconstruct the colormap in viscm
viscm_parameters = {
    "xp": [
        3.444773825208614,
        -17.207400087834856,
        -12.632024921242106,
        -21.656364855235495,
        16.850570926657895,
        55.256368028107175,
        14.676657883179644,
        12.502744839701393,
        40.401295564339051,
        0.90854194115064502,
    ],
    "yp": [
        -1.6304347826086598,
        -24.818840579710098,
        -9.447194719471895,
        6.796617161716227,
        -5.6159420289854722,
        57.065217391304373,
        13.224637681159436,
        3.4420289855072781,
        58.514492753623216,
        0.1811594202898732,
    ],
    "min_Jp": 3.96624472574,
    "max_Jp": 96.5975103734,
}

luts = np.transpose(
    (
        [
            0.02379297,
            0.0261157,
            0.02850455,
            0.03095137,
            0.0334476,
            0.0360304,
            0.03863824,
            0.04128529,
            0.04384689,
            0.04631624,
            0.04870907,
            0.05097181,
            0.05316059,
            0.05519077,
            0.05714277,
            0.05892787,
            0.06062771,
            0.06214595,
            0.06357023,
            0.06480933,
            0.06592827,
            0.06687993,
            0.06766224,
            0.06830946,
            0.06872415,
            0.0689718,
            0.06904334,
            0.06886045,
            0.06844799,
            0.06780027,
            0.06689054,
            0.06568777,
            0.06415629,
            0.06225567,
            0.05994102,
            0.05716433,
            0.0538775,
            0.05003897,
            0.04551728,
            0.04029295,
            0.03446229,
            0.02874366,
            0.02385447,
            0.02127502,
            0.02242508,
            0.0275301,
            0.03578777,
            0.0460108,
            0.05640918,
            0.06656043,
            0.07634217,
            0.08577769,
            0.0948332,
            0.10358394,
            0.11202107,
            0.1201887,
            0.12811962,
            0.13583301,
            0.14334681,
            0.15067405,
            0.15783121,
            0.16483645,
            0.17170112,
            0.17843538,
            0.18504822,
            0.19154762,
            0.19793598,
            0.20422296,
            0.21041472,
            0.21651599,
            0.22253073,
            0.22846216,
            0.23431275,
            0.24008353,
            0.24576942,
            0.25137838,
            0.25691024,
            0.26236467,
            0.2677416,
            0.27303884,
            0.27827346,
            0.28346958,
            0.28867439,
            0.29395695,
            0.29940706,
            0.30508966,
            0.31101811,
            0.31715338,
            0.32345196,
            0.32986905,
            0.33636963,
            0.34292913,
            0.34953992,
            0.35619361,
            0.36288108,
            0.36960242,
            0.37635671,
            0.38314097,
            0.38995328,
            0.39679542,
            0.40366619,
            0.41056374,
            0.41748952,
            0.4244427,
            0.43142299,
            0.43843086,
            0.44546541,
            0.45252642,
            0.45961609,
            0.46673201,
            0.47387346,
            0.48104441,
            0.4882424,
            0.4954658,
            0.5027165,
            0.50999774,
            0.51730448,
            0.52463621,
            0.53199987,
            0.53939166,
            0.54680881,
            0.55425097,
            0.56172938,
            0.56923401,
            0.57676432,
            0.58432014,
            0.59191314,
            0.59953375,
            0.60718079,
            0.6148543,
            0.62255842,
            0.63029849,
            0.63806608,
            0.64586138,
            0.65368467,
            0.66153629,
            0.66942125,
            0.67734101,
            0.68528996,
            0.69326842,
            0.70127674,
            0.70931527,
            0.71738431,
            0.72548409,
            0.73361473,
            0.74177618,
            0.74996816,
            0.75819004,
            0.76644077,
            0.77471875,
            0.78302933,
            0.79137839,
            0.79974926,
            0.80813611,
            0.81657205,
            0.82501275,
            0.83349386,
            0.84198258,
            0.85048492,
            0.8590003,
            0.86751392,
            0.87598709,
            0.88439937,
            0.89263161,
            0.90038304,
            0.90687168,
            0.91166375,
            0.91561895,
            0.91938826,
            0.92318052,
            0.9269946,
            0.93070173,
            0.93405155,
            0.93665497,
            0.93818572,
            0.93886516,
            0.93923641,
            0.93951639,
            0.93979528,
            0.94008554,
            0.9403692,
            0.94071214,
            0.94104779,
            0.94137354,
            0.94172077,
            0.9420958,
            0.94244563,
            0.94274487,
            0.94309703,
            0.94344151,
            0.94369514,
            0.94407978,
            0.94432487,
            0.94468376,
            0.9449135,
            0.94526127,
            0.94544804,
            0.945808,
            0.94601776,
            0.94631082,
            0.94656632,
            0.9467505,
            0.94706511,
            0.94725625,
            0.9474877,
            0.94776129,
            0.9479231,
            0.94816834,
            0.94843142,
            0.94859414,
            0.9488144,
            0.94909331,
            0.9492829,
            0.94943682,
            0.94975423,
            0.94999285,
            0.95015253,
            0.9504141,
            0.95072075,
            0.95095877,
            0.95112839,
            0.95145943,
            0.95179158,
            0.95206534,
            0.95228128,
            0.95264039,
            0.95303147,
            0.95337439,
            0.95367005,
            0.95401622,
            0.95449739,
            0.95494063,
            0.95534717,
            0.95571839,
            0.95624412,
            0.95681749,
            0.95736483,
            0.9578879,
            0.95838862,
            0.95906407,
            0.95978233,
            0.96048784,
            0.96118301,
            0.96187054,
            0.96267628,
            0.96359786,
            0.96452242,
            0.96545346,
            0.9663949,
            0.96735109,
            0.96853232,
            0.96975252,
            0.97100046,
            0.9722811,
            0.97360166,
            0.97499094,
        ],
        [
            0.01131879,
            0.01391783,
            0.01674789,
            0.01980761,
            0.02309557,
            0.02659703,
            0.03032697,
            0.03427332,
            0.03844574,
            0.04276988,
            0.04704341,
            0.05129054,
            0.05550078,
            0.05969933,
            0.06386921,
            0.06803423,
            0.07217737,
            0.07632217,
            0.08045053,
            0.08458326,
            0.0887074,
            0.09283339,
            0.0969619,
            0.10108667,
            0.10522618,
            0.10936788,
            0.1135134,
            0.1176759,
            0.12185004,
            0.12603586,
            0.13023651,
            0.1344553,
            0.13869563,
            0.14296085,
            0.14725413,
            0.15157814,
            0.15593465,
            0.16032384,
            0.16475544,
            0.16922528,
            0.17373863,
            0.17827184,
            0.1827844,
            0.18715937,
            0.19126004,
            0.19503246,
            0.19852956,
            0.20182311,
            0.20496848,
            0.20800345,
            0.21095494,
            0.21383778,
            0.21666923,
            0.21945445,
            0.22220507,
            0.22492545,
            0.22761943,
            0.23029139,
            0.232945,
            0.23558391,
            0.23821051,
            0.24082617,
            0.24343288,
            0.24603239,
            0.24862627,
            0.25121599,
            0.25380393,
            0.25639065,
            0.25897721,
            0.26156482,
            0.2641547,
            0.26674815,
            0.26934657,
            0.27195171,
            0.274567,
            0.27719243,
            0.27983033,
            0.28248333,
            0.2851544,
            0.28784764,
            0.29056213,
            0.2932949,
            0.29603493,
            0.29876097,
            0.30144013,
            0.30404208,
            0.30655158,
            0.3089731,
            0.31131738,
            0.31359848,
            0.31582875,
            0.31801758,
            0.32016861,
            0.32228546,
            0.3243719,
            0.32642829,
            0.32845517,
            0.33045378,
            0.33242493,
            0.33436795,
            0.33628328,
            0.33817163,
            0.34003234,
            0.34186568,
            0.34367166,
            0.34544999,
            0.34720092,
            0.34892444,
            0.35061943,
            0.35228681,
            0.35392679,
            0.35553735,
            0.35711946,
            0.35867374,
            0.36019909,
            0.36169371,
            0.36315988,
            0.36459771,
            0.36600339,
            0.36737862,
            0.36872465,
            0.37004148,
            0.37132268,
            0.37257345,
            0.37379387,
            0.37498382,
            0.37613623,
            0.37725628,
            0.37834438,
            0.37940027,
            0.38042109,
            0.38140311,
            0.38235118,
            0.38326484,
            0.38414358,
            0.38498682,
            0.38579085,
            0.38655416,
            0.38728007,
            0.38796794,
            0.3886171,
            0.38922686,
            0.38979653,
            0.39032549,
            0.39081315,
            0.39125906,
            0.39166297,
            0.39202487,
            0.39234513,
            0.39262465,
            0.39285875,
            0.39304214,
            0.39318804,
            0.39330134,
            0.3933541,
            0.39338391,
            0.39336059,
            0.3933133,
            0.39323839,
            0.39313869,
            0.39303156,
            0.39295965,
            0.39295557,
            0.39315799,
            0.39391119,
            0.39605497,
            0.39998337,
            0.40475771,
            0.40971377,
            0.41464651,
            0.41955776,
            0.42457034,
            0.42991332,
            0.43592086,
            0.44281731,
            0.45031271,
            0.45790211,
            0.46542398,
            0.47282633,
            0.48011752,
            0.48732483,
            0.49440541,
            0.50141998,
            0.50837558,
            0.51525348,
            0.52205415,
            0.52881949,
            0.53556909,
            0.54223396,
            0.54885896,
            0.55550043,
            0.56201556,
            0.56858101,
            0.57503769,
            0.58153866,
            0.58793414,
            0.59439323,
            0.60071983,
            0.60710417,
            0.61341299,
            0.61971646,
            0.6260332,
            0.63225511,
            0.63852001,
            0.64474137,
            0.65092034,
            0.65713626,
            0.66329112,
            0.66941973,
            0.67558021,
            0.68169667,
            0.68777066,
            0.69387233,
            0.69997643,
            0.70599397,
            0.71203573,
            0.71810111,
            0.72411175,
            0.73009422,
            0.73609755,
            0.74212117,
            0.74807095,
            0.75401458,
            0.75997634,
            0.7659557,
            0.77187449,
            0.77777791,
            0.78369726,
            0.78963205,
            0.79554605,
            0.80140962,
            0.80728734,
            0.81317876,
            0.8190834,
            0.82493514,
            0.83077307,
            0.83662327,
            0.84248528,
            0.84835861,
            0.85417838,
            0.85998992,
            0.86581204,
            0.87164424,
            0.877486,
            0.88329814,
            0.88908291,
            0.8948766,
            0.9006787,
            0.90648868,
            0.91230608,
            0.91806899,
            0.9238354,
            0.92961071,
            0.93539672,
            0.94119732,
            0.94701577,
        ],
        [
            0.02001135,
            0.02410049,
            0.0285127,
            0.03327199,
            0.03840892,
            0.04377278,
            0.04914302,
            0.05449872,
            0.05987322,
            0.06527853,
            0.07069504,
            0.07616998,
            0.08164232,
            0.08718911,
            0.0927269,
            0.09833499,
            0.10393204,
            0.10960072,
            0.11525772,
            0.12097641,
            0.12669592,
            0.13244873,
            0.13822862,
            0.14400333,
            0.14983392,
            0.15566404,
            0.16149121,
            0.16735218,
            0.17321659,
            0.17907296,
            0.18491908,
            0.19075078,
            0.19656126,
            0.20233991,
            0.20807104,
            0.21373203,
            0.21929102,
            0.22470403,
            0.22993048,
            0.2348811,
            0.23944453,
            0.24342373,
            0.24654791,
            0.24854699,
            0.24944069,
            0.24964107,
            0.24954394,
            0.24938897,
            0.24925926,
            0.24920029,
            0.24923631,
            0.24934712,
            0.24956187,
            0.24984924,
            0.25022917,
            0.25068854,
            0.25121928,
            0.25182018,
            0.25248939,
            0.25322692,
            0.25402939,
            0.25489122,
            0.25581039,
            0.25678491,
            0.25781293,
            0.25889267,
            0.26002567,
            0.26120803,
            0.26243772,
            0.26371326,
            0.26503318,
            0.26639597,
            0.26779993,
            0.26924355,
            0.27072854,
            0.27224553,
            0.27378857,
            0.27534839,
            0.27691073,
            0.27845714,
            0.27994688,
            0.28132934,
            0.28254139,
            0.28352939,
            0.28426343,
            0.28477016,
            0.28511888,
            0.2853897,
            0.28562523,
            0.28584846,
            0.28606765,
            0.28628369,
            0.28648659,
            0.2866717,
            0.28683846,
            0.28698041,
            0.28709378,
            0.28717794,
            0.2872321,
            0.28725271,
            0.28723935,
            0.28719253,
            0.28710992,
            0.28699145,
            0.2868367,
            0.28664459,
            0.28641544,
            0.28614894,
            0.28584249,
            0.28549799,
            0.28511576,
            0.28469141,
            0.28422699,
            0.28372376,
            0.28317939,
            0.28259016,
            0.28196082,
            0.28129151,
            0.28057453,
            0.27981338,
            0.27901054,
            0.27816595,
            0.27726695,
            0.2763238,
            0.27533659,
            0.27430498,
            0.27321529,
            0.27207747,
            0.27089221,
            0.26965877,
            0.26837161,
            0.26702355,
            0.26562346,
            0.26417019,
            0.2626624,
            0.26109861,
            0.25947144,
            0.25777762,
            0.25602258,
            0.25420436,
            0.25232078,
            0.25036953,
            0.2483481,
            0.24625386,
            0.24408403,
            0.24183578,
            0.23950621,
            0.23709248,
            0.23459188,
            0.23200196,
            0.22930941,
            0.22649861,
            0.22358618,
            0.22057215,
            0.21739359,
            0.2141051,
            0.21063096,
            0.20699978,
            0.20316855,
            0.19908944,
            0.19471496,
            0.19000133,
            0.1847768,
            0.17886461,
            0.17199335,
            0.16449989,
            0.15797658,
            0.15243265,
            0.1469976,
            0.14126571,
            0.13521428,
            0.12907937,
            0.12349501,
            0.11987508,
            0.12047985,
            0.12617587,
            0.1352476,
            0.14599545,
            0.15747549,
            0.16925814,
            0.18117203,
            0.19298222,
            0.20476193,
            0.21648737,
            0.22808422,
            0.23953607,
            0.25094286,
            0.26235208,
            0.27357466,
            0.28472765,
            0.29596437,
            0.30689052,
            0.31799337,
            0.32882896,
            0.33982619,
            0.35056047,
            0.36151349,
            0.37212065,
            0.38293088,
            0.39355561,
            0.40419893,
            0.41491671,
            0.42538398,
            0.43601357,
            0.44654349,
            0.4569744,
            0.46755003,
            0.47796579,
            0.48832714,
            0.49881686,
            0.50919369,
            0.51945918,
            0.52983799,
            0.54024888,
            0.55039796,
            0.56064657,
            0.57099376,
            0.58117647,
            0.59128027,
            0.60146991,
            0.6117441,
            0.62177734,
            0.63179964,
            0.64189483,
            0.65206133,
            0.66202135,
            0.67193144,
            0.68190219,
            0.69193176,
            0.70188796,
            0.71165938,
            0.72147981,
            0.73134717,
            0.74125921,
            0.75096714,
            0.76061378,
            0.77029569,
            0.78001026,
            0.78975461,
            0.79927776,
            0.80875027,
            0.81824276,
            0.82775166,
            0.83727291,
            0.84665036,
            0.85588868,
            0.86512674,
            0.87435845,
            0.88357649,
            0.89277169,
            0.90169092,
            0.91054951,
            0.91934683,
            0.92805132,
            0.93660318,
            0.9448656,
        ],
    )
)
